@@ -389,6 +389,7 @@ def obtain_multi_binaries_items_with_strat(
     """
     dfM = df.copy()
     dfM[q_var_names] = dfM[q_var_names].replace(np.nan,0)
+    ser_strf = df[qdc_strf.var_name].replace(qdc_strf.dic)
     df_sum = pd.DataFrame()
     for l in q_var_names:
         # Create label. 
@@ -397,11 +398,11 @@ def obtain_multi_binaries_items_with_strat(
 
         # Crosstabulate data.
         if percentage:
-            tab = (pd.crosstab(dfM[qdc_strf.var_name], dfM[l], normalize="index")
+            tab = (pd.crosstab(ser_strf, dfM[l], normalize="index")
                    .mul(100)
                    )
         else:
-            tab = pd.crosstab(dfM[qdc_strf.var_name], dfM[l])
+            tab = pd.crosstab(ser_strf, dfM[l])
         per = tab[fetch_value].rename(label) # Fetch "1" value.
         df_sum = pd.concat((df_sum, per), axis=1)
     df_sum = df_sum.loc[qdc_strf.order]
